==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/space/messages/pl/manage.php <==
<?php

return [
    '-' => '-',
    '<strong>Create</strong> Space' => '<strong>Utwórz</strong> nową strefę',
    '<strong>Manage</strong> members' => '<strong>Zarządzaj</strong> członkami',
    '<strong>Members</strong>' => '<strong>Członkowie</strong>',
    '<strong>Security</strong> settings' => '<strong>Ustawienia</strong> bezpieczeństwa',
    '<strong>Space</strong> Modules' => '<strong>Moduły</strong> strefy',
    '<strong>Space</strong> settings' => 'Ustawienia <strong>Strefy</strong>',
    'Actions' => 'Akcje',
    'Activate' => 'Aktywuj',
    'Add <strong>Modules</strong>' => 'Dodaj <strong>Moduły</strong>',
    'Advanced access settings' => 'Zaawansowanie ustawienia dostępu',
    'Archive' => 'Archiwizuj',
    'Are you sure you want to remove this member.' => 'Jesteś pewien że chcesz usunąć tego członka?',
    'Are you sure, that you want to delete this space? All published content will be removed!' => 'Czy jesteś pewien, że chcesz usunąć tę strefę? Cała opublikowana zawartość zostanie usunięta!',
    'As owner of this space you can transfer this role to another administrator in space.' => 'Jako właściciel tej strefy możesz przenieść tę funkcję na innego administratora w strefie.',
    'Cancel Membership' => 'Anuluj Członkowstwo',
    'Choose if new content should be public or private by default' => 'Wybierz czy nowe treści mają być domyślnie publiczne czy prywatne',
    'Choose the kind of membership you want to provide for this workspace.' => 'Wybierz rodzaj członkostwa który chcesz zapewnić tej grupie roboczej.',
    'Choose the security level for this workspace to define the visibleness.' => 'Wybierz poziom bezpieczeństwa dla tej grupy roboczej aby zdefiniować widoczność.',
    'Currently there are no modules available for this space!' => 'Obecnie nie ma modułów dostępnych dla tej strefy!',
    'Delete' => 'Usuń',
    'Don\'t receive notifications for new content' => 'Nie otrzymuj powiadomień o nowych treściach',
    'Hide posts on dashboard' => 'Ukryj wpisy na kokpicie',
    'Invited By' => 'Zaproszony przez',
    'Members' => 'Członkowie',
    'Modules' => 'Moduły',
    'Next' => 'Dalej',
    'Owner' => 'Właściciel',
    'Pending Approvals' => 'Oczekujące do zatwierdzenia',
    'Pending Invites' => 'Oczekujące Zaproszenia',
    'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => 'Uprawnienia są przydzielane do różnych użytkowników-funkcji. W celu edycji uprawnienia, wybierz użytkownika-funkcję którą chcesz edytować i zmień w polu wyboru wartość na żądane uprawnienie.',
    'Please type the name of the space to proceed.' => 'Podaj nazwę strefy aby przejść dalej.',
    'Receive Notifications for new content' => 'Otrzymuj powiadomienia o nowych treściach',
    'Remove from space' => 'Usuń ze strefy',
    'Role' => 'Funkcja',
    'Security' => 'Bezpieczeństwo',
    'Show all' => 'Pokaż wszystkie',
    'Show posts on dashboard' => 'Pokaż wpisy na kokpicie',
    'Space name' => 'Nazwa strefy',
    'Space owner' => 'Właściciel strefy',
    'Stream (Default)' => 'Strumień (Domyślny)',
    'The url contains illegal characters!' => 'Odnośnik zawiera niedozwolone znaki!',
    'This option will hide new content from this space at your dashboard' => 'Ta opcja ukryje nowe treści dla tej strefy na Twoim kokpicie',
    'This option will show new content from this space at your dashboard' => 'Ta opcja pokaże nowe treści dla tej strefy na Twoim kokpicie',
    'Transfer ownership' => 'Przenieś właścicielstwo',
    'Unarchive' => 'Przywróć z archiwum',
    'e.g. example for {baseUrl}/s/example' => 'np. przykład dla {baseUrl}/s/przyklad',
    'never' => 'nigdy',
    'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => '',
    'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => '',
    'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => '',
    'Only global administrators can change this value' => '',
    'Removal of members queued' => '',
    'Remove all members' => '',
    'The URL has already been taken.' => '',
];

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/space/messages/pl/manage.php <==
<?php

return [
    '-' => '-',
    '<strong>Create</strong> Space' => '<strong>Utwórz</strong> nową strefę',
    '<strong>Manage</strong> members' => '<strong>Zarządzaj</strong> członkami',
    '<strong>Members</strong>' => '<strong>Członkowie</strong>',
    '<strong>Security</strong> settings' => '<strong>Ustawienia</strong> bezpieczeństwa',
    '<strong>Space</strong> Modules' => '<strong>Moduły</strong> strefy',
    '<strong>Space</strong> settings' => 'Ustawienia <strong>Strefy</strong>',
    'Actions' => 'Akcje',
    'Enable' => 'Aktywuj',
    'Add <strong>Modules</strong>' => 'Dodaj <strong>Moduły</strong>',
    'Advanced access settings' => 'Zaawansowanie ustawienia dostępu',
    'Archive' => 'Archiwizuj',
    'Are you sure you want to remove this member.' => 'Jesteś pewien że chcesz usunąć tego członka?',
    'Are you sure, that you want to delete this space? All published content will be removed!' => 'Czy jesteś pewien, że chcesz usunąć tę strefę? Cała opublikowana zawartość zostanie usunięta!',
    'As owner of this space you can transfer this role to another administrator in space.' => 'Jako właściciel tej strefy możesz przenieść tę funkcję na innego administratora w strefie.',
    'Cancel Membership' => 'Anuluj Członkowstwo',
    'Choose if new content should be public or private by default' => 'Wybierz czy nowe treści mają być domyślnie publiczne czy prywatne',
    'Choose the kind of membership you want to provide for this workspace.' => 'Wybierz rodzaj członkostwa który chcesz zapewnić tej grupie roboczej.',
    'Choose the security level for this workspace to define the visibleness.' => 'Wybierz poziom bezpieczeństwa dla tej grupy roboczej aby zdefiniować widoczność.',
    'Currently there are no modules available for this space!' => 'Obecnie nie ma modułów dostępnych dla tej strefy!',
    'Delete' => 'Usuń',
    'Don\'t receive notifications for new content' => 'Nie otrzymuj powiadomień o nowych treściach',
    'Hide posts on dashboard' => 'Ukryj wpisy na kokpicie',
    'Invited By' => 'Zaproszony przez',
    'Members' => 'Członkowie',
    'Modules' => 'Moduły',
    'Next' => 'Dalej',
    'Owner' => 'Właściciel',
    'Pending Approvals' => 'Oczekujące do zatwierdzenia',
    'Pending Invites' => 'Oczekujące Zaproszenia',
    'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => 'Uprawnienia są przydzielane do różnych użytkowników-funkcji. W celu edycji uprawnienia, wybierz użytkownika-funkcję którą chcesz edytować i zmień w polu wyboru wartość na żądane uprawnienie.',
    'Please type the name of the space to proceed.' => 'Podaj nazwę strefy aby przejść dalej.',
    'Receive Notifications for new content' => 'Otrzymuj powiadomienia o nowych treściach',
    'Remove from space' => 'Usuń ze strefy',
    'Role' => 'Funkcja',
    'Security' => 'Bezpieczeństwo',
    'Show all' => 'Pokaż wszystkie',
    'Show posts on dashboard' => 'Pokaż wpisy na kokpicie',
    'Space name' => 'Nazwa strefy',
    'Space owner' => 'Właściciel strefy',
    'Stream (Default)' => 'Strumień (Domyślny)',
    'The url contains illegal characters!' => 'Odnośnik zawiera niedozwolone znaki!',
    'This option will hide new content from this space at your dashboard' => 'Ta opcja ukryje nowe treści dla tej strefy na Twoim kokpicie',
    'This option will show new content from this space at your dashboard' => 'Ta opcja pokaże nowe treści dla tej strefy na Twoim kokpicie',
    'Transfer ownership' => 'Przenieś właścicielstwo',
    'Unarchive' => 'Przywróć z archiwum',
    'e.g. example for {baseUrl}/s/example' => 'np. przykład dla {baseUrl}/s/przyklad',
    'never' => 'nigdy',
    'All members excluding moderators and administrators of this Space will be removed. All pending invitations and membership requests will be terminated.' => '',
    'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => '',
    'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => '',
    'Only global administrators can change this value' => '',
    'Removal of members queued' => '',
    'Remove all members' => '',
    'The URL has already been taken.' => '',
];
